燃情岁月 (豆瓣)
Description: 燃情岁月电影简介和剧情介绍,燃情岁月影评、图片、预告片、影讯、论坛、在线购票
Keywords: 燃情岁月,Legends of the Fall,燃情岁月影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.236豆瓣电影Top250

# 燃情岁月 Legends of the Fall (1994)

导演: 爱德华·兹威克
编剧: 威廉·D·威特利夫 / 吉姆·哈里森 / 苏珊·希利迪
主演: 布拉德·皮特 / 安东尼·霍普金斯 / 艾丹·奎因 / 朱莉娅·奥蒙德 / 亨利·托马斯 / 卡琳娜·隆巴德 / 坦图·卡丁诺 / 高登·图托西斯 / 克里斯蒂娜·皮克勒斯 / 约翰·诺瓦克 / 肯尼斯·威尔什 / 尼格尔·本内特 / 基根·麦金托什 / 埃里克·约翰逊 / 兰德尔·斯莱文 / 大卫·卡耶 / 查尔斯·安德烈 / 肯·科齐格 / 温妮·孔 / 巴特熊 / 格雷格·福西特 / 加里·A·赫克 / 马修·罗伯特·凯利
类型: 剧情 / 爱情 / 战争 / 西部
制片国家/地区: 美国
语言: 英语 / 科尼什语
上映日期: 1994-12-16(美国)
片长: 133分钟
又名: 秋日传奇 / 真爱一世情(台) / Legends of the Autumn
IMDb: tt0110322
豆瓣评分
引用
8.8
274147人评价
5星
51.8%
4星
36.4%
3星
10.4%
2星
1.1%
1星
0.4%
好于 97% 西部片
好于 98% 爱情片
想看 看过
评价:
推荐

## 燃情岁月的剧情简介 · · · · · ·

辽阔的西部草原住着一位父亲和他的三个儿子——父亲是退了休的骑兵上校，三个儿子个性鲜明：大儿子艾尔弗莱德（艾丹•奎因 Aidan Quinn 饰）忠厚老实，二儿子特里斯坦（布拉德•皮特 Brad Pitt 饰）狂放不羁，最小的儿子塞缪尔（亨瑞•托马斯Henry Thomas饰）温文尔雅。
父子在大草原的生活随着塞缪尔未婚妻苏珊娜（朱莉娅•奥蒙德 Julia Ormond 饰）的到来而改变。苏珊娜年轻漂亮，给艾尔弗莱德带来了内心的震动。他暗恋她，然而苏珊娜心里却不由自主的迷恋上豪放粗犷的特里斯坦。出于道德的坚守，他们一直压抑着内心的感情。
直到塞缪尔壮烈牺牲在前线，事情有了变化。特里斯坦非常爱戴哥哥，无法面对已经爱上苏珊娜的现实，于是离家出走。而苏珊娜万念俱灰，答应嫁给了艾尔弗莱德，而特里斯坦在草原之外也已结婚生子。事情好像趋于了平静，但特里斯坦妻子... (展开全部) 辽阔的西部草原住着一位父亲和他的三个儿子——父亲是退了休的骑兵上校，三个儿子个性鲜明：大儿子艾尔弗莱德（艾丹•奎因 Aidan Quinn 饰）忠厚老实，二儿子特里斯坦（布拉德•皮特 Brad Pitt 饰）狂放不羁，最小的儿子塞缪尔（亨瑞•托马斯Henry Thomas饰）温文尔雅。
父子在大草原的生活随着塞缪尔未婚妻苏珊娜（朱莉娅•奥蒙德 Julia Ormond 饰）的到来而改变。苏珊娜年轻漂亮，给艾尔弗莱德带来了内心的震动。他暗恋她，然而苏珊娜心里却不由自主的迷恋上豪放粗犷的特里斯坦。出于道德的坚守，他们一直压抑着内心的感情。
直到塞缪尔壮烈牺牲在前线，事情有了变化。特里斯坦非常爱戴哥哥，无法面对已经爱上苏珊娜的现实，于是离家出走。而苏珊娜万念俱灰，答应嫁给了艾尔弗莱德，而特里斯坦在草原之外也已结婚生子。事情好像趋于了平静，但特里斯坦妻子的亡故又令事情有了波澜。 ©豆瓣

## 燃情岁月的演职员 · · · · · · ( 全部 45 )

- 爱德华·兹威克 导演
- 布拉德·皮特 饰 Tristan Ludlow
- 安东尼·霍普金斯 饰 Col. William Ludlow
- 艾丹·奎因 饰 Alfred Ludlow
- 朱莉娅·奥蒙德 饰 Susannah Fincannon
- 亨利·托马斯 饰 Samuel Ludlow

## 燃情岁月的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片1002 · 添加 )

## 燃情岁月的获奖情况 · · · · · · ( 全部 )

- 第67届奥斯卡金像奖
- 最佳摄影
- 约翰·托尔

- 第67届奥斯卡金像奖
- 最佳音响(提名)
- 大卫·E·坎贝尔 / 保罗·马瑟 / 道格拉斯·甘顿 / 克里斯·大卫

- 第52届金球奖
- 电影类 最佳剧情片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  罗马假日

  魂断蓝桥

  爱在日落黄昏时

  英国病人

  恋恋笔记本

  甜蜜蜜

  卡萨布兰卡

  大河恋

  廊桥遗梦

  朗读者

我要写短评

## 燃情岁月的短评 · · · · · · ( 全部 63052 条 )

热门 / 最新 / 好友

### 2292 有用 Lan~die 看过 2006-10-31 15:02:49

生命中的险恶没有什么恐怖，生命中的寂寥没有什么悲愤，生命中的放纵没有什么缺憾，生命中的痛苦与埋没无关，关键是：即使在始终无人注目的暗夜中，你可曾动情地燃烧，像那颗不肯安歇的灵魂一样，为了答谢这一段短暂的岁月？

### 1948 有用 光年‖影视歌三栖民工 看过 2008-11-23 02:24:52

我欣赏忠诚于内心，忠诚于野性的灵魂，因为他们坚持自我所付出的代价，我付不起

### 1366 有用 veronique 看过 2006-06-15 18:51:11

因为他的英俊,我原谅这电影里的一切

### 770 有用 Q。 看过 2010-07-29 04:02:40

每个画面都是那么温情且壮阔，还有那刺痛到灵魂深处的音乐，众人到位的表演。故事虽然并不那么引人入胜，但要表达的思想却是很容易赢得共鸣的。燃情的岁月，一世的真情。★★★★★

### 719 有用 SaturnianAir 看过 2015-07-11 18:58:44

这些人压根没把自己的命当人命来活，他们活的是莽莽草原茫茫大海，活的是如血秋日和从心所欲的野性，遵守的也是血浓于水、成王败寇的丛林法则。社会意义上的人伦法律道德对这种极端到危险的浪漫主义是失效的。我不喜欢这个片子的价值观，然而也无法否认心底对这种生存方式的无限神往。

> 更多短评 63052条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 燃情岁月的影评 · · · · · · ( 全部 1513 条 )

热门 / 最新 / 好友
深蓝 2006-06-13 13:29:23

## 内心的声音

生命是一场放逐和流浪，只是大部分人都将自己交予了俗世，用别人和社会既定的轨道牵拌自己前行，而内心的声音，早在懂得谄媚于人之前就消失殆尽，又或者，永远在耳畔孤独的回响。 我们无法抵挡Tristan从原野上策马呼啸带来的狂野，无法阻止Alfred带着文明进程的光环在... (展开)
4642 137 450回应 收起
公子羽 2006-02-19 02:09:27

## 是一个命犯天煞孤星的男人

这篇影评可能有剧透

很喜欢《燃情岁月》里带着宿命而悲壮的电影配乐，还有那个金灿灿中透露出恬静的秋天颜色。那画面带着神奇的质感，带着苍凉色彩的草原辽阔，阳光似情人的眼波抚摸着崔斯汀的背影和的的作响的马蹄而过。 放浪而狂野的崔斯汀，他的眼睛是深渊也是大海。 然而，崔斯汀注... (展开)
1048 102 81回应 收起
土土猪 2008-01-01 23:10:39

## 爱太痛，永远太远

父母双亡，不是susan的劫数，未婚夫samuel战死沙场，不是susan的劫数，爱上tristan，才是susan的劫数，一个让她终其一生无法承担的劫数。 也许他们眼神的第一次交汇，就注定了一场逃不开的爱恋。Susan面对那个金发飘逸，柔情似水的男子，她的生活开始偷偷变了样子。她逃不脱... (展开)
841 56 165回应 收起
小神仙 2008-09-12 20:36:01

## 那个倔强的小女孩 Isabel

在Isabel被乱枪无意射中的那一刻，我真的震惊了，和Tristan一起。 看到豆瓣上很多人认为Susannah是Trista的挚爱，但我不这样认为。如果说Susannah来到Trista的生活中后找到了自己本性，那么Isabel则是天生就这么倔强，这般狂野，这般自由。他浑身散发出来的野性气质吸引着Tris... (展开)
333 19 61回应 收起
胡安焉 2012-02-20 11:57:38

## 个人的英雄

这篇影评可能有剧透

北美人崇敬熊，大概是源自印第安人的传统，因为熊是北美大陆上最强壮的动物，对熊的崇拜也是对力量和野性的崇拜。我们今天的社会崇拜金钱，我们视富人为成功者。但在印第安部族里，衡量一个人是否出色是依据其身上的“熊性”，说一个人有熊的精神是一种很高的褒扬。而《Legends... (展开)
381 1 35回应 收起
公白 2018-08-11 18:54:00

## 《燃情岁月》有哪些精彩的细节？

这篇影评可能有剧透

苏珊娜，一下火车，电影给了老大眼神特写，艾尔弗莱德一见钟情，之后半途遇见老二特里斯坦，苏珊娜远远的看着特里斯坦骑马走来，内心已经触动，特里斯坦看见苏珊娜，一时间看呆了。 塞缪尔从出场就在谈论战争，于是其走向战场不可避免，但塞缪尔性子柔弱，没有自信，（打网球时... (展开)
314 8 39回应 收起
普通人 2005-11-30 14:20:38

## 属于性情中人的电影——《燃情岁月》

总觉得这部电影是属于性情中人的。因为这是部至情至性的影片讲述的是父子间，兄弟间，情人间那种无须言语而更显深邃的情感。 握着双管猎枪，坐在门前摇椅上老去的父亲鲁德罗上校。看得出他最喜欢的是二儿子屈斯坦，因为他最像年轻时的自己，虽然狂放不羁，却拥有侠士般的剑胆... (展开)
266 37 58回应 收起
云淡风轻 2005-12-26 17:00:59

## “有些人能清楚听见自己心灵的声音，并按这个声音生活，这样的人，不是疯了，就是成了传说。”

“有些人能清楚听见自己心灵的声音，并按这个声音生活，这样的人，不是疯了，就是成了传说。” 影片的开始如是说，我一直都是听着自己的心灵的声音 生活的，可是，我没疯，也没成传说。又或者，我已经疯了，只不过自己不知道，别人也没发现而已。。。 很久以前就听了燃情岁月... (展开)
174 26 35回应 收起
夜雨长安 2006-04-28 15:00:53

## 燃烧的生命

决定看《Legends of the fall》是因为看到它得过奥斯卡最佳摄影。最近的生活索然无味，模棱两可，对电影也没有热情。也许灿烂的风景才能略微刺激我疲惫不堪的神经。 不过意外的，看到老上校把Alfred揽在怀里的时候，眼眶竟莫名的湿润起来，是因为理解万岁么？我不知道... (展开)
100 22 32回应 收起
白夏 2011-12-15 09:59:38

## 爱比死更痛--写给苏珊娜

这篇影评可能有剧透

现在说起来，94年上映的《秋日传奇》也算是一部老片了。我看得不算早，在六七年前才看了这部好友推荐的片子，那时候她喜欢布拉德·皮特，我也是，而且对于雪山下天苍苍野茫茫的牧场颇为心驰神往。因为早知情节的脉络，所以并不觉得故事有多震撼或惆怅伤感。如同一个影评所... (展开)
95 18回应 收起

> 更多影评 1513篇

添加新讨论

## 讨论区 · · · · · ·

苏珊的头发——对苏珊自杀原因一点点想法（有图 长... | 来自青之岛 | 4 回应 | 2022-11-09 00:22:08
总有一种女人，对谁都像在放电。。 | 来自暖 | 10 回应 | 2022-11-04 01:41:47
崔斯汀到底爱苏珊娜还是小伊莎贝尔啊！ | 来自橙妹了啦 | 4 回应 | 2022-11-04 01:40:38
崔斯汀到底爱不爱苏珊娜？ | 来自威玲旺卡 | 12 回应 | 2022-11-04 01:34:11
一家子都是老顽固活该悲剧 | 来自银翼杀手2020 | 4 回应 | 2022-11-01 21:57:29

> 去这部影片的讨论区（全部287条）

## 关于《燃情岁月》的问题 · · · · · · ( 全部19个 )

- 为什么艾尔佛雷德一直不受父亲的喜欢？ 11人回答
- 电影1小时左右 老二离家闯荡 嘶吼之后醒来全裸那里啥意思？？ 9人回答

> 全部19个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 优酷视频 VIP免费观看
- 爱奇艺视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 深情即是一桩悲剧，必得以死来句读。 (眠去)
- 【内牛满面】 (影志)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 神兆
  4分钟前 看过
- 又是凌晨两点半
  6分钟前 想看
- J&L
  11分钟前 想看

397726人看过 / 216822人想看

订阅燃情岁月的评论:
feed: rss 2.0